@@ -50,6 +50,8 @@ _set_instance_theme(Ipc_Instance *inst)
    inst->config->temporary = EINA_TRUE;
 }
 
+#define IPC_INSTANCE_OPT_UNSET  0xff
+
 static void
 _configure_instance(Ipc_Instance *inst)
 {
@@ -118,34 +120,33 @@ _configure_instance(Ipc_Instance *inst)
         config->temporary = EINA_TRUE;
      }
 
-   if (inst->login_shell != 0xff)
+   if (inst->login_shell != IPC_INSTANCE_OPT_UNSET)
      {
         inst->config->login_shell = inst->login_shell;
         inst->config->temporary = EINA_TRUE;
      }
-   inst->login_shell = inst->config->login_shell;
 
    if (inst->xterm_256color)
      {
         inst->config->xterm_256color = EINA_TRUE;
         inst->config->temporary = EINA_TRUE;
      }
-   if (inst->video_mute != 0xff)
+   if (inst->video_mute != IPC_INSTANCE_OPT_UNSET)
      {
         config->mute = inst->video_mute;
         config->temporary = EINA_TRUE;
      }
-   if (inst->cursor_blink != 0xff)
+   if (inst->cursor_blink != IPC_INSTANCE_OPT_UNSET)
      {
         config->disable_cursor_blink = !inst->cursor_blink;
         config->temporary = EINA_TRUE;
      }
-   if (inst->visual_bell != 0xff)
+   if (inst->visual_bell != IPC_INSTANCE_OPT_UNSET)
      {
         config->disable_visual_bell = !inst->visual_bell;
         config->temporary = EINA_TRUE;
      }
-   if (inst->active_links != 0xff)
+   if (inst->active_links != IPC_INSTANCE_OPT_UNSET)
      {
         config->active_links = !!inst->active_links;
         config->active_links_email = inst->config->active_links;
@@ -332,7 +333,8 @@ main_ipc_new(Ipc_Instance *inst)
         nargv[i++] = "-g";
         nargv[i++] = geom;
      }
-   if (inst->login_shell)
+   if ((inst->login_shell != IPC_INSTANCE_OPT_UNSET)
+       && (inst->login_shell != 0))
      {
         nargv[i++] = "-l";
      }
@@ -368,7 +370,8 @@ main_ipc_new(Ipc_Instance *inst)
      {
         nargv[i++] = "-2";
      }
-   if (inst->active_links)
+   if ((inst->active_links != IPC_INSTANCE_OPT_UNSET)
+       && (inst->active_links != 0))
      {
         nargv[i++] = "--active-links";
      }
@@ -377,15 +380,18 @@ main_ipc_new(Ipc_Instance *inst)
         nargv[i++] = "-e";
         nargv[i++] = (char *)inst->cmd;
      }
-   if (inst->video_mute)
+   if ((inst->video_mute != IPC_INSTANCE_OPT_UNSET)
+       && (inst->video_mute != 0))
      {
         nargv[i++] = "-m";
      }
-   if (inst->cursor_blink)
+   if ((inst->cursor_blink != IPC_INSTANCE_OPT_UNSET)
+       && (inst->cursor_blink != 0))
      {
         nargv[i++] = "-c";
      }
-   if (inst->visual_bell)
+   if ((inst->visual_bell != IPC_INSTANCE_OPT_UNSET)
+       && (inst->visual_bell != 0))
      {
         nargv[i++] = "-G";
      }
@@ -494,13 +500,13 @@ static Ecore_Getopt options = {
       ECORE_GETOPT_STORE_TRUE('F', "fullscreen",
                               gettext_noop("Go into the fullscreen mode from the start")),
       ECORE_GETOPT_STORE_TRUE('I', "iconic",
-                              gettext_noop("Go into an iconic state from the start")),
+                              gettext_noop("Start iconified")),
       ECORE_GETOPT_STORE_TRUE('B', "borderless",
-                              gettext_noop("Become a borderless managed window")),
+                              gettext_noop("Start borderless")),
       ECORE_GETOPT_STORE_TRUE('O', "override",
-                              gettext_noop("Become an override-redirect window")),
+                              gettext_noop("Start as a override-redirect window")),
       ECORE_GETOPT_STORE_TRUE('M', "maximized",
-                              gettext_noop("Become maximized from the start")),
+                              gettext_noop("Start maximized")),
       ECORE_GETOPT_STORE_TRUE('W', "nowm",
                               gettext_noop("Terminology is run without a window manager")),
       ECORE_GETOPT_STORE_TRUE('H', "hold",
@@ -799,6 +805,7 @@ exit:
    return EINA_TRUE;
 }
 
+
 EAPI_MAIN int
 elm_main(int argc, char **argv)
 {
@@ -809,11 +816,11 @@ elm_main(int argc, char **argv)
    Eina_Bool cmd_options = EINA_FALSE;
    double scale = -1.0; /* unset */
    Ipc_Instance instance = {
-        .login_shell = 0xff, /* unset */
-        .active_links = 0xff, /* unset */
-        .video_mute = 0xff, /* unset */
-        .cursor_blink = 0xff, /* unset */
-        .visual_bell = 0xff, /* unset */
+        .login_shell = IPC_INSTANCE_OPT_UNSET,
+        .active_links = IPC_INSTANCE_OPT_UNSET,
+        .video_mute = IPC_INSTANCE_OPT_UNSET,
+        .cursor_blink = IPC_INSTANCE_OPT_UNSET,
+        .visual_bell = IPC_INSTANCE_OPT_UNSET,
         .startup_id = getenv("DESKTOP_STARTUP_ID"),
         .w = 1,
         .h = 1,
@@ -1042,6 +1049,9 @@ elm_main(int argc, char **argv)
    elm_theme_overlay_add(NULL, theme_path_get("default"));
    elm_theme_overlay_add(NULL, config_theme_path_get(instance.config));
 
+   if (instance.login_shell == IPC_INSTANCE_OPT_UNSET)
+     instance.login_shell = instance.config->login_shell;
+
    if ((!single) && (instance.config->multi_instance))
      {
         char cwdbuf[4096];
